# Owners

- See [CONTRIBUTING.md](CONTRIBUTING.md) for general contribution guidelines.

## Core Developers

- David Rubinstein (@drubinstein, Spotify)
- Peter Sobot (@psobot, Spotify)
- Charae Tongg (@charaizlabs, Spotify)

The development of this project is led by [Spotify's Audio Intelligence Lab](https://research.atspotify.com/audio-intelligence/).